SectionHeader

Struct SectionHeader 

pub struct SectionHeader {
    pub pointer: u64,
    pub csize: u32,
    pub size: u32,
    pub chksum: u32,
    pub btype: u8,
    pub flags: u8,
}
The BPX Section Header.

Fields

pointer: u64

Data pointer.

Offset: +0

csize: u32

Size in bytes after compression.

Offset: +8

size: u32

Size in bytes before compression.

Offset: +12

chksum: u32

Data checksum.

Offset: +16

btype: u8

Type byte.

Offset: +20

flags: u8

Flags (see FLAG_* constants).

Offset: +21

Implementations

Source

impl SectionHeader

pub fn read<TReader: Read>(reader: &mut TReader) -> Result<(u32, SectionHeader)>

Attempts to read a BPX Section Header from an IO backend.

Arguments
  • reader: the IO backend to read from.

returns: Result<(u32, SectionHeader), Error>

Errors

Returns an Error if the data could not be read from the IO backend.

pub fn new() -> SectionHeader

Creates a new empty BPX Section Header.

pub fn is_huge_section(&self) -> bool

Checks if this section is huge (greater than 100Mb).

pub fn get_checksum(&self) -> u32

Computes the checksum for this header.

pub fn write<TWriter: Write>(&self, writer: &mut TWriter) -> Result<()>

Attempts to write this header to an IO backend.

Arguments
  • writer: the IO backend to write to.

returns: Result<(), Error>

Errors

Returns an Error if the data could not be written to the IO backend.