DebugSymbols

Struct DebugSymbols 

pub struct DebugSymbols { /* private fields */ }
Provides support for debug symbols to BPXSD object.

Implementations

Source

impl DebugSymbols

pub fn new() -> DebugSymbols

Creates a new DebugSymbols.

pub fn lookup(&self, hash: u64) -> Option<&str>

Performs a lookup for a given hash value in this symbol list. Returns None if the symbol does not exist.

Arguments
  • hash: the hash for which to search the symbol name.

returns: Option<&str>

Examples
use bpx::sd::DebugSymbols;
use bpx::utils::hash;

let symbols = DebugSymbols::new();
assert!(symbols.lookup(hash("Test")).is_none());
pub fn push(&mut self, symbol: &str)

Pushes a new symbol in this symbol list.

Arguments
  • symbol: the name of the symbol to push.
Examples
use bpx::sd::DebugSymbols;
use bpx::utils::hash;

let mut symbols = DebugSymbols::new();
symbols.push("Test");
assert!(symbols.lookup(hash("Test")).is_some());
pub fn write(&self, obj: &mut Object)

Attach this symbol list to a BPXSD object.

Arguments
  • obj: the object to attach debug information to.
Examples
use bpx::sd::{DebugSymbols, Object};
use bpx::utils::hash;

let mut symbols = DebugSymbols::new();
symbols.push("Test");
assert!(symbols.lookup(hash("Test")).is_some());
let mut obj = Object::new();
symbols.write(&mut obj);
assert!(obj.get("__debug__").is_some());
pub fn read(obj: &Object) -> Result<DebugSymbols>

Attempts to read debug information from a BPXSD object.

Arguments
  • obj: the object to read debug information from.

returns: Result<DebugSymbols, Error>

Errors

An Error is returned in case the object does not provide debug information or if the debug information could not be read.

Examples
use bpx::sd::{DebugSymbols, Object};
use bpx::utils::hash;

let mut symbols = DebugSymbols::new();
symbols.push("Test");
let mut obj = Object::new();
symbols.write(&mut obj);
let symbols1 = DebugSymbols::read(&obj).unwrap();
assert!(symbols1.lookup(hash("Test")).is_some());
use bpx::sd::{DebugSymbols, Object};

let mut obj = Object::new();
DebugSymbols::read(&obj).unwrap();