PackageDecoder

Struct PackageDecoder 

pub struct PackageDecoder<'a, TBackend: IoBackend> { /* private fields */ }
Represents a BPX Package decoder.

Implementations

Source

impl<'a, TBackend: IoBackend> PackageDecoder<'a, TBackend>

pub fn read( decoder: &mut Decoder<TBackend>, ) -> Result<PackageDecoder<'_, TBackend>>

Creates a new PackageDecoder by reading from a BPX decoder.

Arguments
  • decoder: the BPX Decoder backend to use.

returns: Result<PackageDecoder, Error>

Errors

An Error is returned if some sections/headers could not be loaded.

Examples
//TODO: Implement
pub fn get_variant(&self) -> [u8; 2]

Gets the two bytes of BPXP variant.

pub fn get_architecture(&self) -> Architecture

Gets the target CPU Architecture for this BPXP.

pub fn get_platform(&self) -> Platform

Gets the target Platform for this BPXP.

pub fn read_metadata(&mut self) -> Result<Option<Object>>

Reads the metadata section of this BPXP if any. Returns None if there is no metadata in this BPXP.

Errors

An Error is returned in case of corruption or system error.

Examples
//TODO: Implement
pub fn read_object_table(&mut self) -> Result<ObjectTable>

Reads the object table of this BPXP.

Errors

An Error is returned in case of corruption or system error.

Examples
//TODO: Implement
pub fn get_object_name(&mut self, obj: &ObjectHeader) -> Result<&str>

Gets the name of an object; loads the string if its not yet loaded.

Arguments
  • obj: the object header to load the actual name for.

returns: Result<&str, Error>

Errors

An Error is returned if the name could not be read.

Examples
//TODO: Implement
pub fn unpack_object<TWrite: Write>( &mut self, obj: &ObjectHeader, out: &mut TWrite, ) -> Result<u64>

Unpacks an object to a raw stream. Returns the number of bytes read if the operation has succeeded.

Arguments
  • obj: the object header.
  • out: the raw Write to use as destination.

returns: Result<u64, Error>

Errors

An Error is returned if the object could not be unpacked.

Examples
//TODO: Implement